==> spring-integration-amqp-5.5.18-sources.jar: org/springframework/integration/amqp/dsl/AmqpInboundChannelAdapterDMLCSpec.java <==
/*
 * Copyright 2017-2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.amqp.dsl;

import java.util.function.Consumer;

import org.springframework.amqp.rabbit.listener.DirectMessageListenerContainer;

/**
 * Spec for an inbound channel adapter with a {@link DirectMessageListenerContainer}.
 *
 * @author Gary Russell
 * @author Artem Bilan
 *
 * @since 5.0
 *
 */
public class AmqpInboundChannelAdapterDMLCSpec
		extends AmqpInboundChannelAdapterSpec<AmqpInboundChannelAdapterDMLCSpec, DirectMessageListenerContainer> {

	protected AmqpInboundChannelAdapterDMLCSpec(DirectMessageListenerContainer listenerContainer) {
		super(new DirectMessageListenerContainerSpec(listenerContainer));
	}

	public AmqpInboundChannelAdapterDMLCSpec configureContainer(Consumer<DirectMessageListenerContainerSpec> configurer) {
		configurer.accept((DirectMessageListenerContainerSpec) this.listenerContainerSpec);
		return this;
	}

}

==> spring-integration-amqp-6.4.3-sources.jar: org/springframework/integration/amqp/dsl/AmqpInboundChannelAdapterDMLCSpec.java <==
/*
 * Copyright 2017-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.integration.amqp.dsl;

import java.util.function.Consumer;

import org.springframework.amqp.rabbit.listener.DirectMessageListenerContainer;

/**
 * Spec for an inbound channel adapter with a {@link DirectMessageListenerContainer}.
 *
 * @author Gary Russell
 * @author Artem Bilan
 *
 * @since 5.0
 *
 */
public class AmqpInboundChannelAdapterDMLCSpec
		extends AmqpInboundChannelAdapterSpec<AmqpInboundChannelAdapterDMLCSpec, DirectMessageListenerContainer> {

	protected AmqpInboundChannelAdapterDMLCSpec(DirectMessageListenerContainer listenerContainer) {
		super(new DirectMessageListenerContainerSpec(listenerContainer));
	}

	public AmqpInboundChannelAdapterDMLCSpec configureContainer(
			Consumer<DirectMessageListenerContainerSpec> configurer) {

		configurer.accept((DirectMessageListenerContainerSpec) this.listenerContainerSpec);
		return this;
	}

}
